@@ -45,6 +45,7 @@ def yield_sources(
     path: Path,
     include: Pattern[str],
     exclude: Pattern[str],
+    extend_exclude: Pattern[str],
     gitignore: PathSpec,
     reporter: Report,
 ) -> Generator[Path, None, None]:
@@ -54,6 +55,7 @@ def yield_sources(
     :param path: A path to start searching from.
     :param include: regex pattern to be included.
     :param exclude: regex pattern to be excluded.
+    :param extend_exclude: regex pattern to be excluded in addition to `exclude`.
     :param gitignore: gitignore PathSpec object.
     :param reporter: a `report.Report` object.
     :returns: generator of `.py` files paths.
@@ -82,6 +84,11 @@ def yield_sources(
             reporter.ignored_path(entry_path, EXCLUDE)
             continue
 
+        # Compute extended exclusions.
+        if is_excluded(entry_path, extend_exclude):
+            reporter.ignored_path(entry_path, EXCLUDE)
+            continue
+
         # Compute `.gitignore`.
         if gitignore.match_file(entry_path):
             reporter.ignored_path(entry_path, GITIGNORE)
@@ -107,6 +114,7 @@ def yield_sources(
             dir_,
             include,
             exclude,
+            extend_exclude,
             gitignore + regexu.get_gitignore(dir_) if gitignore is not None else None,
             reporter,
         )
@@ -250,7 +258,7 @@ def get_local_import_from_path(
             fpath = os.path.join(
                 *dirparts[:i],
                 *packages[:-1] if level > 0 else "",
-                f"{packages[-1]}{PY_EXTENSION}",
+                f"{packages[-1] if packages else '__init__'}{PY_EXTENSION}",
             )
         if os.path.isfile(fpath):
             return Path(fpath)
@@ -289,14 +297,15 @@ def get_module_path(paths: Set[Path], module: str) -> Optional[Path]:
     :param module: module name.
     :returns: `module` path if exist else None.
     """
-    module = module.split(".")[0]
-    for path in paths:
-        name = str(path.parts[-1]).split(".")[0]
-        if name == module:
-            if str(path).endswith(PY_EXTENSION):
-                return path
-            else:
-                return Path(os.path.join(path, __INIT__))
+    if module is not None:
+        module = module.split(".")[0]
+        for path in paths:
+            name = str(path.parts[-1]).split(".")[0]
+            if name == module:
+                if str(path).endswith(PY_EXTENSION):
+                    return path
+                else:
+                    return Path(os.path.join(path, __INIT__))
     # Path not found.
     return None
 
