@@ -123,6 +123,10 @@ class Refactor:
                     remove_from_children(parent, orelse, len(orelse), white_list)
                     white_list = set(orelse)
 
+                if hasattr(parent, "finalbody"):
+                    finalbody = getattr(parent, "finalbody")
+                    remove_from_children(parent, finalbody, len(finalbody), white_list)
+
                 children = ast.iter_child_nodes(parent)
                 remove_from_children(parent, children, body_len, white_list)
 
