@@ -14,7 +14,6 @@ from ._exceptions import ReadPermissionError, UnexpandableImportStar, Unparsable
 # Constants.
 PY38_PLUS = sys.version_info >= (3, 8)
 PY39_PLUS = sys.version_info >= (3, 9)
-IMPORT_EXCEPTIONS = {"ImportError", "ImportWarning", "ModuleNotFoundError"}
 __ALL__ = "__all__"
 NAMES_TO_SKIP = frozenset(
     {
@@ -157,7 +156,7 @@ class SourceAnalyzer(ast.NodeVisitor):
         if not PY38_PLUS and source_lines is None:
             # Bad class usage.
             raise ValueError("Please provide source lines for Python < 3.8.")
-        self._has_all = False  # True if the source has `__all__` dunder.
+        self._has_all = False  # True if the source has an `__all__` dunder.
         self._lines = source_lines
         self._import_stats = ImportStats(set(), set())
         self._imports_to_skip: Set[Union[_nodes.Import, _nodes.ImportFrom]] = set()
@@ -233,73 +232,29 @@ class SourceAnalyzer(ast.NodeVisitor):
                     #: Issue: https://github.com/hadialqattan/pycln/issues/41
                     pass
 
-    @recursive
-    def visit_Try(self, node: ast.Try):
-        """Support any try/except block that has import error(s).
-
-        Add any import that placed on try/except block that has import error
-        to `self._imports_to_skip`.
-
-        exp:- two of these imports would not be used and should not be removed:
-            >>> try:
-            >>>     import foo2
-            >>> except ModuleNotFoundError:
-            >>>     import foo3
-            >>> else:
-            >>>     import foo38
-
-        supported exceptions (`IMPORT_EXCEPTIONS`):
-            - ModuleNotFoundError
-            - ImportError.
-            - ImportWarning.
-
-        supported blocks:
-            - try.
-            - except.
-            - else.
-        """
-        is_skip_case = False
-
-        def add_imports_to_skip(body: List[ast.stmt]) -> None:
-            """Add all try/except/else blocks body import children to
-            `self._imports_to_skip`.
-
-            :param body: ast.List to iterate over.
-            """
-            for child in body:
-                if hasattr(child, "names"):
-                    self._imports_to_skip.add(child)  # type: ignore
-
-        for handler in node.handlers:
-            if hasattr(handler.type, "elts"):
-                for name in getattr(handler.type, "elts", []):
-                    if hasattr(name, "id") and name.id in IMPORT_EXCEPTIONS:
-                        is_skip_case = True
-                        break
-            elif hasattr(handler.type, "id"):
-                if getattr(handler.type, "id", "") in IMPORT_EXCEPTIONS:
-                    is_skip_case = True
-            if is_skip_case:
-                add_imports_to_skip(handler.body)
-
-        if is_skip_case:
-            for body in (node.body, node.orelse):
-                add_imports_to_skip(body)
-
     @recursive
     def visit_AnnAssign(self, node: ast.AnnAssign):
-        #: Support string type annotations.
-        #: >>> from typing import List
-        #: >>> foo: "List[str]" = []
+        #: Support (nested)string type annotations.
+        #: >>> from ast import Import
+        #: >>> from typing import Tuple
+        #: >>>
+        #: >>> foo: "List[Import]" = []
+        #: >>>
+        #: >>> bar: "List['Import']" = []
         self._visit_string_type_annotation(node)
 
     @recursive
     def visit_arg(self, node: ast.arg):
         # Support Python ^3.8 type comments.
         self._visit_type_comment(node)
-        #: Support arg string type annotations.
+        #: Support arg (nested)string type annotations.
+        #: >>> from ast import Import
         #: >>> from typing import Tuple
-        #: >>> def foo(bar: "Tuple[str, int]"):
+        #: >>>
+        #: >>> def foo(bar: "Tuple[Import]"):
+        #: ...     pass
+        #: >>>
+        #: >>> def bar(foo: "Tuple['Import']"):
         #: ...     pass
         self._visit_string_type_annotation(node)
 
@@ -307,9 +262,14 @@ class SourceAnalyzer(ast.NodeVisitor):
     def visit_FunctionDef(self, node: FunctionDefT):
         # Support Python ^3.8 type comments.
         self._visit_type_comment(node)
-        #: Support string type annotations.
+        #: Support (nested)string type annotations.
+        #: >>> from ast import Import
         #: >>> from typing import List
-        #: >>> def foo() -> 'List[str]':
+        #: >>>
+        #: >>> def foo() -> "List[Import]":
+        #: >>>     pass
+        #: >>>
+        #: >>> def bar() -> "List['Import']":
         #: >>>     pass
         self._visit_string_type_annotation(node)
 
@@ -403,7 +363,7 @@ class SourceAnalyzer(ast.NodeVisitor):
             annotation = node.annotation
         else:
             annotation = node.returns
-        self._parse_string(annotation)  # type: ignore
+        self._parse_string(annotation, True)  # type: ignore
 
     def _visit_type_comment(
         self, node: Union[ast.Assign, ast.arg, FunctionDefT]
@@ -423,7 +383,7 @@ class SourceAnalyzer(ast.NodeVisitor):
                 mode = "func_type"
             try:
                 tree = parse_ast(type_comment, mode=mode)
-                self._add_name_attr(tree)
+                self._add_name_attr_const(tree)
             except UnparsableFile:
                 #: Ignore errors when it's not a valid type comment.
                 #:
@@ -433,13 +393,15 @@ class SourceAnalyzer(ast.NodeVisitor):
                 #: Issue: https://github.com/hadialqattan/pycln/issues/58
                 pass
 
-    def _parse_string(self, node: Union[ast.Constant, ast.Str]) -> None:
+    def _parse_string(
+        self, node: Union[ast.Constant, ast.Str], is_str_annotation: bool = False
+    ) -> None:
         # Parse string names/attrs.
         if isinstance(node, (ast.Constant, ast.Str)):
             val = getattr(node, "value", "") or getattr(node, "s", "")
             if val and isinstance(val, str):
                 tree = parse_ast(val, mode="eval")
-                self._add_name_attr(tree)
+                self._add_name_attr_const(tree, is_str_annotation)
 
     def _add_concatenated_list_names(self, node: ast.BinOp) -> None:
         #: Safely add `["x", "y"] + ["i", "j"]`
@@ -460,14 +422,16 @@ class SourceAnalyzer(ast.NodeVisitor):
                 if value and isinstance(value, str):
                     self._source_stats.name_.add(value)
 
-    def _add_name_attr(self, tree: ast.AST):
-        # Add any `ast.Name` or `ast.Attribute`
+    def _add_name_attr_const(self, tree: ast.AST, is_str_annotation: bool = False):
+        # Add any `ast.Name`, `ast.Attribute`, and (`ast.Constant` if is_str_annotation)
         # child to `self._source_stats`.
         for node in ast.walk(tree):
             if isinstance(node, ast.Name):
                 self._source_stats.name_.add(node.id)
             elif isinstance(node, ast.Attribute):
                 self._source_stats.attr_.add(node.attr)
+            elif is_str_annotation and isinstance(node, ast.Constant):
+                self._source_stats.name_.add(node.value)
 
     def _get_py38_import_node(self, node: ast.Import) -> _nodes.Import:
         # Convert any Python < 3.8 `ast.Import`
@@ -538,7 +502,7 @@ class SourceAnalyzer(ast.NodeVisitor):
     def has_all(self) -> bool:
         """`self._has_all` getter.
 
-        :returns: True if the source includes `__all__` dunder.
+        :returns: True if the source includes an `__all__` dunder.
         """
         return self._has_all
 
@@ -561,7 +525,7 @@ class ImportablesAnalyzer(ast.NodeVisitor):
     def __init__(self, path: Path):
         self._not_importables: Set[Union[ast.Name, str]] = set()
         self._importables: Set[str] = set()
-        self._has_all = False  # True if the source has `__all__` dunder.
+        self._has_all = False  # True if the source has an `__all__` dunder.
         self._path = path
 
     @recursive
